@@ -5,8 +5,8 @@
 from syst3m.classes.config import *
 from syst3m.classes import objects
 
-# the default cache object class.
-class Default(objects.Object):
+# the cache object class.
+class Cache(objects.Object):
 	def __init__(self, path=None):
 		if path == None: path = f"{HOME}/.cache/"
 		if not os.path.exists(path): os.mkdir(path)
@@ -55,7 +55,7 @@ class Default(objects.Object):
 
 
 # the default cache.
-cache = Default()
+cache = Cache()
 
 # the webserver cache object class.
 class WebServer(objects.Thread):
@@ -67,7 +67,7 @@ class WebServer(objects.Thread):
 		default={},
 	):
 		objects.Thread.__init__(self)
-		self.__cache__ = Default(path=path)
+		self.__cache__ = Cache(path=path)
 		self.assign({
 			"sleeptime":3,
 			"id":id,
@@ -81,6 +81,8 @@ class WebServer(objects.Thread):
 			"id":id,
 			"data":data,
 			"token":self.token(),
+			"cache":self.__cache__.path,
+			"cache_id":self.id,
 		})
 		try:
 			response = requests.get(f'http://{self.host}:{self.port}/set?{encoded}')
@@ -106,6 +108,8 @@ class WebServer(objects.Thread):
 			"group":group,
 			"id":id,
 			"token":self.token(),
+			"cache":self.__cache__.path,
+			"cache_id":self.id,
 		})
 		try:
 			response = requests.get(f'http://{self.host}:{self.port}/get?{encoded}')
@@ -132,9 +136,9 @@ class WebServer(objects.Thread):
 		cli.show_server_banner = lambda *x: None
 		@app.route('/get')
 		def get():
-			#token = flask.request.args.get('token')
-			#if token != self.token():
-			#	return r3sponse.error_response(f"Provided an invalid token {token}.").json()
+			token = flask.request.args.get('token')
+			if token != Cache(path=flask.request.args.get('cache')).get(flask.request.args.get('cache_id'), id="token"):
+				return r3sponse.error_response(f"Provided an invalid token {token}.").json()
 			group = flask.request.args.get('group')
 			id = flask.request.args.get('id')
 			if id in ["none", "null", "None"]: id = None
@@ -147,16 +151,15 @@ class WebServer(objects.Thread):
 					value = self.cache[group][id]
 			except KeyError:
 				return r3sponse.error_response(f"There is no data cached for {tag}.").json()
-			print("VALUE:",value)
 			return r3sponse.success_response(f"Successfully retrieved {tag}.", {
 				"group":group,
 				"data":value,
 			}).json()
 		@app.route('/set')
 		def set():
-			#token = flask.request.args.get('token')
-			#if token != self.token():
-			#	return r3sponse.error_response(f"Provided an invalid token {token}.").json()
+			token = flask.request.args.get('token')
+			if token != Cache(path=flask.request.args.get('cache')).get(flask.request.args.get('cache_id'), id="token"):
+				return r3sponse.error_response(f"Provided an invalid token {token}.").json()
 			group = flask.request.args.get('group')
 			id = flask.request.args.get('id')
 			if id in ["none", "null", "None"]: id = None
@@ -172,9 +175,9 @@ class WebServer(objects.Thread):
 			return r3sponse.success_response(f"Successfully cached {tag}.").json()
 		@app.route('/active')
 		def active():
-			#token = flask.request.args.get('token')
-			#if token != self.token():
-			#	return r3sponse.error_response(f"Provided an invalid token {token}.").json()
+			token = flask.request.args.get('token')
+			if token != Cache(path=flask.request.args.get('cache')).get(flask.request.args.get('cache_id'), id="token"):
+				return r3sponse.error_response(f"Provided an invalid token {token}.").json()
 			return r3sponse.success_response(f"Active.").json()
 		#def run__(self, app, host, port):
 		#	app.run(host=host, port=port)
@@ -188,6 +191,8 @@ class WebServer(objects.Thread):
 	def running(self):
 		encoded = urllib.parse.urlencode({
 			"token":self.token(),
+			"cache":self.__cache__.path,
+			"cache_id":self.id,
 		})
 		try:
 			requests.get(f'http://{self.host}:{self.port}/active?{encoded}')
